
Subpackages
-----------

.. toctree::
   :maxdepth: 4

   czsc.data


.. automodapi:: czsc
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: czsc.analyze
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.signals
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.sensors
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.traders
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.utils
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.aphorism
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:

.. automodapi:: czsc.enum
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.envs
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.objects
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:


.. automodapi:: czsc.strategies
   :members:
   :undoc-members:
   :no-main-docstr:
   :no-inheritance-diagram:
